SystemOrganization addCategory: #'HelpSystem-Tests-Builders'!
SystemOrganization addCategory: #'HelpSystem-Tests-Core-Model'!
SystemOrganization addCategory: #'HelpSystem-Tests-Core-UI'!

Object subclass: #AdvancedHelpBrowserDummy
	instanceVariableNames: 'rootTopic isOpen'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HelpSystem-Tests-Core-UI'!

!AdvancedHelpBrowserDummy commentStamp: 'tbn 5/3/2010 19:30' prior: 0!
This is a dummy for a custom Help browser that can be registered as a replacement for the HelpBrowser class.

Instance Variables
	rootTopic:		<HelpTopic>

rootTopic
	- The root help topic
!

!AdvancedHelpBrowserDummy methodsFor: 'initialize-release' stamp: 'tbn 5/3/2010 19:34'!
initialize
	isOpen := false! !

!AdvancedHelpBrowserDummy methodsFor: 'testing' stamp: 'tbn 5/3/2010 19:32'!
isOpen
	^isOpen! !

!AdvancedHelpBrowserDummy methodsFor: 'mocking' stamp: 'tbn 5/3/2010 19:32'!
open
	isOpen := true! !

!AdvancedHelpBrowserDummy methodsFor: 'mocking' stamp: 'tbn 5/3/2010 19:33'!
rootTopic
	^rootTopic! !

!AdvancedHelpBrowserDummy methodsFor: 'mocking' stamp: 'tbn 5/3/2010 19:33'!
rootTopic: aTopic
	rootTopic := aTopic! !

TestCase subclass: #ClassAPIHelpBuilderTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HelpSystem-Tests-Builders'!

!ClassAPIHelpBuilderTest methodsFor: 'testing' stamp: 'LaurentLaffont 9/2/2010 15:55'!
testBuildingTraits
	|topic|
	topic := ClassAPIHelpBuilder 
				buildHelpTopicFrom: TSortable .				 
	self assert: topic subtopics size = 2.
	self assert: topic subtopics first title = 'Instance side'.
	self assert: topic subtopics last title = 'Class side'
 

 ! !

!ClassAPIHelpBuilderTest methodsFor: 'testing' stamp: 'tbn 3/8/2010 16:33'!
testDefaultBuilding
	|topic|
	topic := ClassAPIHelpBuilder 
				buildHelpTopicFrom: Integer.				 
	self assert: topic subtopics size = 2.
	self assert: topic subtopics first title = 'Instance side'.
	self assert: topic subtopics last title = 'Class side'
 

 ! !

!ClassAPIHelpBuilderTest methodsFor: 'testing' stamp: 'tbn 3/8/2010 16:32'!
testMethodsButNoSubclasses
	|topic|
	topic := ClassAPIHelpBuilder 
				buildHierarchicalHelpTopicFrom: Integer 
				withSubclasses: false 
				withMethods: true.
	self assert: topic subtopics size = 2.
	self assert: topic subtopics first title = 'Instance side'.
	self assert: topic subtopics last title = 'Class side'
 

 ! !

TestCase subclass: #HelpBrowserTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HelpSystem-Tests-Core-UI'!

!HelpBrowserTest methodsFor: 'accessing' stamp: 'tbn 5/3/2010 19:35'!
defaultTestClass
	^HelpBrowser! !

!HelpBrowserTest methodsFor: 'testing' stamp: 'tbn 5/3/2010 20:22'!
testDefaultHelpBrowser
	
	| current replacement instance |
	current := self defaultTestClass defaultHelpBrowser.
	replacement := AdvancedHelpBrowserDummy.
	[
	  self defaultTestClass defaultHelpBrowser: replacement.
	  self assert: self defaultTestClass defaultHelpBrowser == replacement.
 
	  instance := self defaultTestClass open.
	  self assert: instance rootTopic notNil.
	  self assert: instance isOpen.
	] ensure: [ self defaultTestClass defaultHelpBrowser: current ]
	 ! !

!HelpBrowserTest methodsFor: 'testing' stamp: 'tbn 5/3/2010 19:28'!
testDefaultHelpBrowserIsReplacable
	
	| current replacement instance |
	"save the one that is registered"
	current := self defaultTestClass defaultHelpBrowser.
	replacement := AdvancedHelpBrowserDummy.
	[
	  self defaultTestClass defaultHelpBrowser: replacement.
	  self assert: self defaultTestClass defaultHelpBrowser == replacement.	  
	  instance := self defaultTestClass open.
	  
	] ensure: [
		self defaultTestClass defaultHelpBrowser: current
	]
	 ! !

!HelpBrowserTest methodsFor: 'testing' stamp: 'tbn 5/3/2010 18:43'!
testLazyDefaultHelpBrowser
	
	self assert: self defaultTestClass defaultHelpBrowser notNil! !

!HelpBrowserTest methodsFor: 'testing' stamp: 'tbn 12/20/2010 17:05'!
testOpen
	|block|
	block := [
		|browser|
		browser := self defaultTestClass open.
		World doOneCycleNow. 
		browser close ].
	self shouldnt: block raise: Error


		! !

TestCase subclass: #HelpIconsTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HelpSystem-Tests-Core-UI'!

!HelpIconsTest methodsFor: 'accessing' stamp: 'tbn 2/12/2010 14:23'!
defaultTestClass 
	^HelpIcons! !

!HelpIconsTest methodsFor: 'testing' stamp: 'tbn 3/3/2010 00:50'!
testIconCaching
	 
	| first second |
	#(bookIcon pageIcon refreshIcon) do: [:iconSymbol |
		first := self defaultTestClass iconNamed: iconSymbol.
		second := self defaultTestClass iconNamed: iconSymbol.	
		self assert: first notNil.
		self assert: first == second.
	]
	! !

TestCase subclass: #HelpTopicListItemWrapperTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HelpSystem-Tests-Core-UI'!

!HelpTopicListItemWrapperTest methodsFor: 'accessing' stamp: 'tbn 2/12/2010 13:16'!
defaultTestClass 
	^HelpTopicListItemWrapper 
	! !

!HelpTopicListItemWrapperTest methodsFor: 'testing' stamp: 'tbn 3/5/2010 21:46'!
testDisplayLabel
	|instance|
	instance := self defaultTestClass with: (HelpTopic named: 'My Topic').
	self assert: instance asString = 'My Topic'
	! !

TestCase subclass: #HelpTopicTest
	instanceVariableNames: 'topic'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HelpSystem-Tests-Core-Model'!

!HelpTopicTest methodsFor: 'accessing' stamp: 'tbn 3/5/2010 21:47'!
defaultTestClass
	^HelpTopic ! !

!HelpTopicTest methodsFor: 'running' stamp: 'tbn 3/5/2010 21:49'!
setUp
	super setUp.
	topic := self defaultTestClass new.! !

!HelpTopicTest methodsFor: 'testing' stamp: 'tbn 3/8/2010 16:44'!
testAddingSubtopic

	|subtopic returned|
	subtopic := self defaultTestClass named: 'Subtopic'.
	returned := topic addSubtopic: subtopic.
	self assert: returned == subtopic.
	self assert: (topic subtopics includes: subtopic) ! !

!HelpTopicTest methodsFor: 'testing' stamp: 'tbn 3/6/2010 00:07'!
testInitialization

	self assert: topic title = 'Unnamed Topic'.
	self assert: topic key isEmpty.
	self assert: topic contents isEmpty ! !

!HelpTopicTest methodsFor: 'testing' stamp: 'tbn 3/6/2010 00:06'!
testInstanceCreation

	|instance|
	instance := self defaultTestClass named: 'My Topic'.
	self assert: instance title = 'My Topic'.
! !

!HelpTopicTest methodsFor: 'testing' stamp: 'tbn 3/6/2010 00:06'!
testSortOrder

	|a b c sorted |
	a := self defaultTestClass named: 'A'.
	b := self defaultTestClass named: 'B'.
	c := self defaultTestClass named: 'C'.
	sorted := (OrderedCollection with: b with: c with: a) asSortedCollection.
	self assert: sorted first = a.
	self assert: sorted last = c.
	! !
